/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.crunch.impl.mr.plan;

import org.apache.hadoop.conf.Configuration;

/**
 * Collection of Configuration keys and various constants used when planning MapReduce jobs for a
 * pipeline.
 */
public final class PlanningParameters {

  public static final String MULTI_OUTPUT_PREFIX = "out";

  public static final String CRUNCH_WORKING_DIRECTORY = "crunch.work.dir";

  /**
   * Configuration key under which a <a href="http://www.graphviz.org">DOT</a> file containing the
   * pipeline job graph is stored by the planner.
   *
   * @deprecated use {@link DotfileUtil#setPipelineDotfileOutputDir(Configuration, String)} instead
   */
  @Deprecated
  public static final String PIPELINE_PLAN_DOTFILE = "crunch.planner.dotfile";

  public static final String DEBUG_DOTFILES_ENABLED  = "crunch.internals.dotfiles";

  /**
   * Configuration key under which a directory URI can be stored where MapReduce pipeline job plans in
   * <a href="http://www.graphviz.org">DOT</a> format are stored. The dot files are only written if this configuration
   * parameter is set.
   */
  public static final String PIPELINE_DOTFILE_OUTPUT_DIR = "crunch.planner.dotfile.outputdir";

  public static final String JOB_NAME_MAX_STACK_LENGTH = "crunch.job.name.max.stack.length";

  private PlanningParameters() {
  }
}
